@@ -91,7 +91,7 @@ def hg_timers():
     import mercurial.hg
     return [
         Timer('hg_lib.{method_name}', mercurial.hg.localrepo.localrepository, 'heads',
-              'branchtags', 'tags'),
+              'branchmap', 'tags'),
         Timer('hg_lib.{method_name}', mercurial.cmdutil, 'walkchangerevs'),
     ]
 
